*  Directory for SAS code, data and output - remember trailing slash;

%let SAMPDIR=C:\HOW\DelGobbo\;

*  Library containing the sample data;

libname sample "&SAMPDIR" access=read;

*  Library to store styles and tagsets;

libname mylib "&SAMPDIR";

*  Set the ODS search path for styles and tagsets;

ods path mylib.tmplmst(update)
         sashelp.tmplmst(read);

*  Include recent version of the ExcelXP ODS tagset;

%include "&SAMPDIR.ExcelXP.sas";

*  Create a custom style based on the stock "sansPrinter" style;

proc template;
  define style styles.XLsansPrinter;
    parent=styles.sansprinter;
    
    /*  Change attributes of the column headings  */
    
    style header from header /
      font_size = 10pt
      just      = center
      vjust     = bottom;
      
    /*  Change attributes of the blank lines  */

    style notecontent from notecontent /
      bordertopwidth    = 1
      borderbottomwidth = 1
      borderleftwidth   = 1
      borderrightwidth  = 1;

    /*  Used to create bold text  */

    style data_bold from data /
      font_weight = bold;

    /*  Used to center text  */

    style data_center from data /
      just = center;

    /*  Used to convert SAS date values to Excel date values  */

    style data_date9 from data /
      tagattr = 'type:DateTime format:ddmmmyyyy';
  end;
run; quit;

*  Create a SAS table that is used for the range flags worksheet;

data Legend;
length LabFlag 8 Range $30;
LabFlag = 0; Range = 'Normal';                       output;
LabFlag = 1; Range = 'Low';                          output;
LabFlag = 3; Range = 'Clinically Significant Low';   output;
LabFlag = 2; Range = 'High';                         output;
LabFlag = 4; Range = 'Clinically Significant High';  output;
label Range   = 'Range Flags'
      LabFlag = 'Color';
run;

*;
*  Create a format for traffic lighting, based
*  on the lab flag values
*
*  0 : white    Normal
*  1 : #CCFFFF  Low
*  3 : #FFCC00  Clinically Significant Low
*  2 : #9999FF  High
*  4 : #FF6600  Clinically Significant High
*;

proc format;
  value FlagFmt  0 = 'white'
                 1 = '#CCFFFF'
                 3 = '#9999FF'
                 2 = '#FFCC00'
                 4 = '#FF6600';
run; quit;